@@ -1061,7 +1061,7 @@ GtkWidget *create_girl_app()
 	       girl->selected_streams_bitrate);
 	GIRL_DEBUG_MSG("girl->selected_streams_samplerate: %s\n",
 	       girl->selected_streams_samplerate);
-	GIRL_DEBUG_MSG("girl->selected_channels: %s\n",
+	GIRL_DEBUG_MSG("girl->selected_channels: %0x\n",
 	       girl->selected_streams_channels);
 
 	gnome_config_pop_prefix();
